# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/auth.proto\x12\x0cNKikimrProto\"\xdd\x0c\n\x0bTAuthConfig\x12=\n\x12UserRegistryConfig\x18\x01 \x01(\x0b\x32!.NKikimrProto.TUserRegistryConfig\x12+\n\tTVMConfig\x18\x02 \x01(\x0b\x32\x18.NKikimrProto.TTVMConfig\x12\x19\n\x11StaffApiUserToken\x18\x03 \x01(\t\x12\x31\n\x10\x42lackBoxEndpoint\x18\x04 \x01(\t:\x17\x62lackbox.yandex-team.ru\x12\x43\n\x15\x41\x63\x63\x65ssServiceEndpoint\x18\x05 \x01(\t:$as.private-api.cloud.yandex.net:4286\x12Q\n\x1aUserAccountServiceEndpoint\x18\x06 \x01(\t:-api-adapter.private-api.cloud.yandex.net:8443\x12T\n\x1dServiceAccountServiceEndpoint\x18\x07 \x01(\t:-api-adapter.private-api.cloud.yandex.net:8443\x12/\n\rStaffEndpoint\x18\n \x01(\t:\x18staff-api.yandex-team.ru\x12\x1b\n\rGrpcCacheSize\x18\x10 \x01(\r:\x04\x31\x30\x32\x34\x12\"\n\x13GrpcSuccessLifeTime\x18\x11 \x01(\x04:\x05\x36\x30\x30\x30\x30\x12 \n\x11GrpcErrorLifeTime\x18\x12 \x01(\x04:\x05\x31\x30\x30\x30\x30\x12\x19\n\x0bUseBlackBox\x18\x14 \x01(\x08:\x04true\x12\x1f\n\x10UseAccessService\x18\x15 \x01(\x08:\x05\x66\x61lse\x12/\n CacheAccessServiceAuthentication\x18\x16 \x01(\x08:\x05\x66\x61lse\x12.\n\x1f\x43\x61\x63heAccessServiceAuthorization\x18\x17 \x01(\x08:\x05\x66\x61lse\x12\x16\n\x08UseStaff\x18\x19 \x01(\x08:\x04true\x12$\n\x15UseUserAccountService\x18\x1a \x01(\x08:\x05\x66\x61lse\x12\'\n\x18UseServiceAccountService\x18\x1b \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x10UseLoginProvider\x18\x1d \x01(\x08:\x04true\x12!\n\x13UseAccessServiceTLS\x18\x1f \x01(\x08:\x04true\x12&\n\x18UseUserAccountServiceTLS\x18  \x01(\x08:\x04true\x12)\n\x1bUseServiceAccountServiceTLS\x18! \x01(\x08:\x04true\x12%\n\x17\x43\x61\x63heUserAccountService\x18% \x01(\x08:\x04true\x12(\n\x1a\x43\x61\x63heServiceAccountService\x18& \x01(\x08:\x04true\x12\x1d\n\x10TvmServiceDomain\x18( \x01(\t:\x03tvm\x12 \n\x0e\x42lackBoxDomain\x18) \x01(\t:\x08\x62lackbox\x12\x1f\n\x13\x41\x63\x63\x65ssServiceDomain\x18* \x01(\t:\x02\x61s\x12#\n\x11UserAccountDomain\x18+ \x01(\t:\x08passport\x12\x1e\n\rServiceDomain\x18, \x01(\t:\x07service\x12\x1d\n\x0f\x44omainLoginOnly\x18- \x01(\x08:\x04true\x12\x19\n\rRefreshPeriod\x18\x32 \x01(\t:\x02\x31s\x12\x17\n\x0bRefreshTime\x18\x33 \x01(\t:\x02\x31h\x12\x14\n\x08LifeTime\x18\x34 \x01(\t:\x02\x31h\x12\x17\n\nExpireTime\x18\x35 \x01(\t:\x03\x32\x34h\x12\x19\n\rTVMExpireTime\x18\x36 \x01(\t:\x02\x32m\x12\x1f\n\x13MinErrorRefreshTime\x18\x37 \x01(\t:\x02\x31s\x12\x1f\n\x13MaxErrorRefreshTime\x18\x38 \x01(\t:\x02\x31m\x12=\n\x0cPathToRootCA\x18< \x01(\t:\'/etc/ssl/certs/YandexInternalRootCA.pem\x12/\n AccessServiceGrpcKeepAliveTimeMs\x18\x46 \x01(\r:\x05\x31\x30\x30\x30\x30\x12\x31\n#AccessServiceGrpcKeepAliveTimeoutMs\x18G \x01(\r:\x04\x31\x30\x30\x30\"$\n\x13TUserRegistryConfig\x12\r\n\x05Query\x18\x01 \x01(\t\"\xc2\x01\n\nTTVMConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x14\n\x0cServiceTVMId\x18\x02 \x01(\r\x12\x12\n\nPublicKeys\x18\x03 \x01(\t\x12\x1e\n\x10UpdatePublicKeys\x18\x04 \x01(\x08:\x04true\x12-\n\x1eUpdatePublicKeysSuccessTimeout\x18\x05 \x01(\x04:\x05\x38\x32\x38\x30\x30\x12*\n\x1eUpdatePublicKeysFailureTimeout\x18\x06 \x01(\x04:\x02\x31\x30\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TAUTHCONFIG._serialized_start=45
  _TAUTHCONFIG._serialized_end=1674
  _TUSERREGISTRYCONFIG._serialized_start=1676
  _TUSERREGISTRYCONFIG._serialized_end=1712
  _TTVMCONFIG._serialized_start=1715
  _TTVMCONFIG._serialized_end=1909
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/proto/dq_tasks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.library.yql.dq.proto import dq_transport_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__transport__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/library/yql/dq/proto/dq_tasks.proto\x12\rNYql.NDqProto\x1a\x19google/protobuf/any.proto\x1a&library/cpp/actors/protos/actors.proto\x1a+ydb/library/yql/dq/proto/dq_transport.proto\"\xa6\x01\n\x08TProgram\x12\x16\n\x0eRuntimeVersion\x18\x01 \x01(\r\x12\x0b\n\x03Raw\x18\x02 \x01(\x0c\x12\x33\n\x08Settings\x18\x03 \x01(\x0b\x32!.NYql.NDqProto.TProgram.TSettings\x1a@\n\tTSettings\x12\x12\n\nHasMapJoin\x18\x01 \x01(\x08\x12\x0f\n\x07HasSort\x18\x02 \x01(\x08\x12\x0e\n\x06HasUdf\x18\x03 \x01(\x08\"8\n\x06TDqUri\x12\x10\n\x08Protocol\x18\x01 \x01(\t\x12\x0b\n\x03Uri\x18\x02 \x01(\t\x12\x0f\n\x07ShardId\x18\x03 \x01(\r\"\x80\x01\n\tTEndpoint\x12)\n\x07\x41\x63torId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorIdH\x00\x12\x12\n\x08TabletId\x18\x02 \x01(\x06H\x00\x12$\n\x03Uri\x18\x03 \x01(\x0b\x32\x15.NYql.NDqProto.TDqUriH\x00\x42\x0e\n\x0c\x45ndpointType\"\xf8\x02\n\x08TChannel\x12\n\n\x02Id\x18\x01 \x01(\x04\x12>\n\x10TransportVersion\x18\x02 \x01(\x0e\x32$.NYql.NDqProto.EDataTransportVersion\x12\x11\n\tSrcTaskId\x18\x03 \x01(\x04\x12\x11\n\tDstTaskId\x18\x04 \x01(\x04\x12-\n\x0bSrcEndpoint\x18\x05 \x01(\x0b\x32\x18.NYql.NDqProto.TEndpoint\x12-\n\x0b\x44stEndpoint\x18\x06 \x01(\x0b\x32\x18.NYql.NDqProto.TEndpoint\x12\x14\n\x0cIsPersistent\x18\x07 \x01(\x08\x12\x10\n\x08InMemory\x18\x08 \x01(\x08\x12<\n\x11\x43heckpointingMode\x18\t \x01(\x0e\x32!.NYql.NDqProto.ECheckpointingMode\x12\x36\n\x0eWatermarksMode\x18\n \x01(\x0e\x32\x1e.NYql.NDqProto.EWatermarksMode\"\x10\n\x0eTUnionAllInput\"|\n\x0cTSourceInput\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12&\n\x08Settings\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x36\n\x0eWatermarksMode\x18\x03 \x01(\x0e\x32\x1e.NYql.NDqProto.EWatermarksMode\"0\n\x0bTSortColumn\x12\x0e\n\x06\x43olumn\x18\x01 \x01(\t\x12\x11\n\tAscending\x18\x02 \x01(\x08\">\n\x0bTMergeInput\x12/\n\x0bSortColumns\x18\x01 \x03(\x0b\x32\x1a.NYql.NDqProto.TSortColumn\"\xfe\x01\n\nTTaskInput\x12)\n\x08\x43hannels\x18\x01 \x03(\x0b\x32\x17.NYql.NDqProto.TChannel\x12\x31\n\x08UnionAll\x18\n \x01(\x0b\x32\x1d.NYql.NDqProto.TUnionAllInputH\x00\x12-\n\x06Source\x18\x0b \x01(\x0b\x32\x1b.NYql.NDqProto.TSourceInputH\x00\x12+\n\x05Merge\x18\x0c \x01(\x0b\x32\x1a.NYql.NDqProto.TMergeInputH\x00\x12.\n\tTransform\x18\x1e \x01(\x0b\x32\x1b.NYql.NDqProto.TDqTransformB\x06\n\x04Type\"\x10\n\x0eTTaskOutputMap\"d\n\x13TRangePartitionInfo\x12\x14\n\x0c\x45ndKeyPrefix\x18\x01 \x01(\x0c\x12\x13\n\x0bIsInclusive\x18\x02 \x01(\x08\x12\x0f\n\x07IsPoint\x18\x03 \x01(\x08\x12\x11\n\tChannelId\x18\x04 \x01(\x04\"g\n\x19TTaskOutputRangePartition\x12\x12\n\nKeyColumns\x18\x01 \x03(\t\x12\x36\n\nPartitions\x18\x02 \x03(\x0b\x32\".NYql.NDqProto.TRangePartitionInfo\"\x16\n\x14TTaskOutputBroadcast\"G\n\x18TTaskOutputHashPartition\x12\x12\n\nKeyColumns\x18\x01 \x03(\t\x12\x17\n\x0fPartitionsCount\x18\x02 \x01(\r\"\x14\n\x12TTaskOutputEffects\"G\n\x0fTTaskOutputSink\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12&\n\x08Settings\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xc4\x03\n\x0bTTaskOutput\x12)\n\x08\x43hannels\x18\x01 \x03(\x0b\x32\x17.NYql.NDqProto.TChannel\x12,\n\x03Map\x18\n \x01(\x0b\x32\x1d.NYql.NDqProto.TTaskOutputMapH\x00\x12\x42\n\x0eRangePartition\x18\x0b \x01(\x0b\x32(.NYql.NDqProto.TTaskOutputRangePartitionH\x00\x12@\n\rHashPartition\x18\x0c \x01(\x0b\x32\'.NYql.NDqProto.TTaskOutputHashPartitionH\x00\x12\x38\n\tBroadcast\x18\r \x01(\x0b\x32#.NYql.NDqProto.TTaskOutputBroadcastH\x00\x12\x34\n\x07\x45\x66\x66\x65\x63ts\x18\x0e \x01(\x0b\x32!.NYql.NDqProto.TTaskOutputEffectsH\x00\x12.\n\x04Sink\x18\x0f \x01(\x0b\x32\x1e.NYql.NDqProto.TTaskOutputSinkH\x00\x12.\n\tTransform\x18\x1e \x01(\x0b\x32\x1b.NYql.NDqProto.TDqTransformB\x06\n\x04Type\"k\n\x0cTDqTransform\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x11\n\tInputType\x18\x02 \x01(\x0c\x12\x12\n\nOutputType\x18\x03 \x01(\x0c\x12&\n\x08Settings\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\xc8\x03\n\x07TDqTask\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x0f\n\x07StageId\x18\t \x01(\r\x12*\n\x08\x45xecuter\x18\x02 \x01(\x0b\x32\x18.NYql.NDqProto.TEndpoint\x12(\n\x07Program\x18\x03 \x01(\x0b\x32\x17.NYql.NDqProto.TProgram\x12:\n\nParameters\x18\x04 \x03(\x0b\x32&.NYql.NDqProto.TDqTask.ParametersEntry\x12)\n\x06Inputs\x18\x05 \x03(\x0b\x32\x19.NYql.NDqProto.TTaskInput\x12+\n\x07Outputs\x18\x06 \x03(\x0b\x32\x1a.NYql.NDqProto.TTaskOutput\x12\"\n\x04Meta\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0f\x43reateSuspended\x18\x08 \x01(\x08\x12\x13\n\x0bRateLimiter\x18\n \x01(\t\x12\x1b\n\x13RateLimiterResource\x18\x0b \x01(\t\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.NYql.NDqProto.TData:\x02\x38\x01*Q\n\x0f\x45RuntimeVersion\x12\x1f\n\x1bRUNTIME_VERSION_UNSPECIFIED\x10\x00\x12\x1d\n\x17RUNTIME_VERSION_YQL_1_0\x10\xa0\x8d\x06*U\n\x12\x45\x43heckpointingMode\x12\x1e\n\x1a\x43HECKPOINTING_MODE_DEFAULT\x10\x00\x12\x1f\n\x1b\x43HECKPOINTING_MODE_DISABLED\x10\x01*L\n\x0f\x45WatermarksMode\x12\x1b\n\x17WATERMARKS_MODE_DEFAULT\x10\x00\x12\x1c\n\x18WATERMARKS_MODE_DISABLED\x10\x01\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.proto.dq_tasks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TDQTASK_PARAMETERSENTRY._options = None
  _TDQTASK_PARAMETERSENTRY._serialized_options = b'8\001'
  _ERUNTIMEVERSION._serialized_start=2862
  _ERUNTIMEVERSION._serialized_end=2943
  _ECHECKPOINTINGMODE._serialized_start=2945
  _ECHECKPOINTINGMODE._serialized_end=3030
  _EWATERMARKSMODE._serialized_start=3032
  _EWATERMARKSMODE._serialized_end=3108
  _TPROGRAM._serialized_start=171
  _TPROGRAM._serialized_end=337
  _TPROGRAM_TSETTINGS._serialized_start=273
  _TPROGRAM_TSETTINGS._serialized_end=337
  _TDQURI._serialized_start=339
  _TDQURI._serialized_end=395
  _TENDPOINT._serialized_start=398
  _TENDPOINT._serialized_end=526
  _TCHANNEL._serialized_start=529
  _TCHANNEL._serialized_end=905
  _TUNIONALLINPUT._serialized_start=907
  _TUNIONALLINPUT._serialized_end=923
  _TSOURCEINPUT._serialized_start=925
  _TSOURCEINPUT._serialized_end=1049
  _TSORTCOLUMN._serialized_start=1051
  _TSORTCOLUMN._serialized_end=1099
  _TMERGEINPUT._serialized_start=1101
  _TMERGEINPUT._serialized_end=1163
  _TTASKINPUT._serialized_start=1166
  _TTASKINPUT._serialized_end=1420
  _TTASKOUTPUTMAP._serialized_start=1422
  _TTASKOUTPUTMAP._serialized_end=1438
  _TRANGEPARTITIONINFO._serialized_start=1440
  _TRANGEPARTITIONINFO._serialized_end=1540
  _TTASKOUTPUTRANGEPARTITION._serialized_start=1542
  _TTASKOUTPUTRANGEPARTITION._serialized_end=1645
  _TTASKOUTPUTBROADCAST._serialized_start=1647
  _TTASKOUTPUTBROADCAST._serialized_end=1669
  _TTASKOUTPUTHASHPARTITION._serialized_start=1671
  _TTASKOUTPUTHASHPARTITION._serialized_end=1742
  _TTASKOUTPUTEFFECTS._serialized_start=1744
  _TTASKOUTPUTEFFECTS._serialized_end=1764
  _TTASKOUTPUTSINK._serialized_start=1766
  _TTASKOUTPUTSINK._serialized_end=1837
  _TTASKOUTPUT._serialized_start=1840
  _TTASKOUTPUT._serialized_end=2292
  _TDQTRANSFORM._serialized_start=2294
  _TDQTRANSFORM._serialized_end=2401
  _TDQTASK._serialized_start=2404
  _TDQTASK._serialized_end=2860
  _TDQTASK_PARAMETERSENTRY._serialized_start=2789
  _TDQTASK_PARAMETERSENTRY._serialized_end=2860
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/local.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import follower_group_pb2 as ydb_dot_core_dot_protos_dot_follower__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bydb/core/protos/local.proto\x12\x0cNKikimrLocal\x1a,library/cpp/actors/protos/interconnect.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1cydb/core/protos/tablet.proto\x1a ydb/core/protos/subdomains.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a$ydb/core/protos/follower_group.proto\"\\\n\x13TTabletAvailability\x12\x33\n\x04Type\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x10\n\x08MaxCount\x18\x02 \x01(\x04\"\xd4\x01\n\x0fTEvRegisterNode\x12\x0e\n\x06HiveId\x18\x01 \x01(\x06\x12\x36\n\x0fServicedDomains\x18\x02 \x03(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12:\n\x0eSystemLocation\x18\x03 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12=\n\x12TabletAvailability\x18\x04 \x03(\x0b\x32!.NKikimrLocal.TTabletAvailability\"k\n\x15TEvRegisterNodeResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06HiveId\x18\x02 \x01(\x06\x12\x16\n\x0eHiveGeneration\x18\x03 \x01(\r\"K\n\x0cTLocalConfig\x12;\n\x10ResourceProfiles\x18\x01 \x03(\x0b\x32!.NKikimrSchemeOp.TResourceProfile\"l\n\x07TEvPing\x12\x0e\n\x06HiveId\x18\x01 \x01(\x06\x12\x16\n\x0eHiveGeneration\x18\x02 \x01(\r\x12\r\n\x05Purge\x18\x03 \x01(\x08\x12*\n\x06\x43onfig\x18\x04 \x01(\x0b\x32\x1a.NKikimrLocal.TLocalConfig\"L\n\x10TEvDeadTabletAck\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x12\n\nFollowerId\x18\x03 \x01(\r\"\xc0\x01\n\tTEvStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x15\n\rInbootTablets\x18\x02 \x01(\x04\x12\x15\n\rOnlineTablets\x18\x03 \x01(\x04\x12\x13\n\x0b\x44\x65\x61\x64Tablets\x18\x04 \x01(\x04\x12\x17\n\x0f\x41vailableWeight\x18\x05 \x01(\x04\x12\x34\n\x0fResourceMaximum\x18\x08 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x11\n\tStartTime\x18\x07 \x01(\x04\"\xe6\x01\n\rTEvBootTablet\x12\x33\n\x04Info\x18\x01 \x01(\x0b\x32%.NKikimrTabletBase.TTabletStorageInfo\x12\x1b\n\x13SuggestedGeneration\x18\x02 \x01(\r\x12;\n\x08\x42ootMode\x18\x03 \x01(\x0e\x32\x17.NKikimrLocal.EBootMode:\x10\x42OOT_MODE_LEADER\x12\x32\n\rFollowerGroup\x18\x04 \x01(\x0b\x32\x1b.NKikimrHive.TFollowerGroup\x12\x12\n\nFollowerId\x18\x05 \x01(\r\"I\n\rTEvStopTablet\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nFollowerId\x18\x02 \x01(\r\x12\x12\n\nGeneration\x18\x03 \x01(\r\"o\n\x0fTEvTabletStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\x12\x12\n\nGeneration\x18\x03 \x01(\r\x12\x12\n\nFollowerId\x18\x04 \x01(\r\x12\x12\n\x06Reason\x18\x05 \x01(\r:\x02\x33\x34\"P\n\x13TEvEnumerateTablets\x12\x39\n\nTabletType\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\"\xbe\x02\n\x19TEvEnumerateTabletsResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12G\n\nTabletInfo\x18\x02 \x03(\x0b\x32\x33.NKikimrLocal.TEvEnumerateTabletsResult.TTabletInfo\x1a\xab\x01\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12;\n\x08\x42ootMode\x18\x03 \x01(\x0e\x32\x17.NKikimrLocal.EBootMode:\x10\x42OOT_MODE_LEADER\x12\x12\n\nFollowerId\x18\x04 \x01(\r\"\x86\x02\n\x0eTEvSyncTablets\x12?\n\rInbootTablets\x18\x01 \x03(\x0b\x32(.NKikimrLocal.TEvSyncTablets.TTabletInfo\x12?\n\rOnlineTablets\x18\x02 \x03(\x0b\x32(.NKikimrLocal.TEvSyncTablets.TTabletInfo\x1ar\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12)\n\x08\x42ootMode\x18\x03 \x01(\x0e\x32\x17.NKikimrLocal.EBootMode\x12\x12\n\nFollowerId\x18\x04 \x01(\r\";\n\x13TEvTabletMetricsAck\x12\x10\n\x08TabletId\x18\x01 \x03(\x06\x12\x12\n\nFollowerId\x18\x02 \x03(\r\"6\n\x0cTEvReconnect\x12\x0e\n\x06HiveId\x18\x01 \x01(\x06\x12\x16\n\x0eHiveGeneration\x18\x02 \x01(\r*9\n\tEBootMode\x12\x14\n\x10\x42OOT_MODE_LEADER\x10\x00\x12\x16\n\x12\x42OOT_MODE_FOLLOWER\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.local_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EBOOTMODE._serialized_start=2343
  _EBOOTMODE._serialized_end=2400
  _TTABLETAVAILABILITY._serialized_start=259
  _TTABLETAVAILABILITY._serialized_end=351
  _TEVREGISTERNODE._serialized_start=354
  _TEVREGISTERNODE._serialized_end=566
  _TEVREGISTERNODERESULT._serialized_start=568
  _TEVREGISTERNODERESULT._serialized_end=675
  _TLOCALCONFIG._serialized_start=677
  _TLOCALCONFIG._serialized_end=752
  _TEVPING._serialized_start=754
  _TEVPING._serialized_end=862
  _TEVDEADTABLETACK._serialized_start=864
  _TEVDEADTABLETACK._serialized_end=940
  _TEVSTATUS._serialized_start=943
  _TEVSTATUS._serialized_end=1135
  _TEVBOOTTABLET._serialized_start=1138
  _TEVBOOTTABLET._serialized_end=1368
  _TEVSTOPTABLET._serialized_start=1370
  _TEVSTOPTABLET._serialized_end=1443
  _TEVTABLETSTATUS._serialized_start=1445
  _TEVTABLETSTATUS._serialized_end=1556
  _TEVENUMERATETABLETS._serialized_start=1558
  _TEVENUMERATETABLETS._serialized_end=1638
  _TEVENUMERATETABLETSRESULT._serialized_start=1641
  _TEVENUMERATETABLETSRESULT._serialized_end=1959
  _TEVENUMERATETABLETSRESULT_TTABLETINFO._serialized_start=1788
  _TEVENUMERATETABLETSRESULT_TTABLETINFO._serialized_end=1959
  _TEVSYNCTABLETS._serialized_start=1962
  _TEVSYNCTABLETS._serialized_end=2224
  _TEVSYNCTABLETS_TTABLETINFO._serialized_start=2110
  _TEVSYNCTABLETS_TTABLETINFO._serialized_end=2224
  _TEVTABLETMETRICSACK._serialized_start=2226
  _TEVTABLETMETRICSACK._serialized_end=2285
  _TEVRECONNECT._serialized_start=2287
  _TEVRECONNECT._serialized_end=2341
# @@protoc_insertion_point(module_scope)



import ydb.core.protos.blobstorage_config_pb2 as kikimr_bsconfig
import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table

description = 'List pdisks'


def add_options(p):
    p.add_argument('--show-pdisk-usage', action='store_true', help='Show columns with PDisk usage')
    table.TableOutput([], col_units=[]).add_options(p)


def do(args):
    base_config = common.fetch_base_config()
    node_to_fqdn = common.fetch_node_to_fqdn_map()

    all_columns = [
        'NodeId:PDiskId',
        'NodeId',
        'PDiskId',
        'FQDN',
        'Path',
        'Type',
        'Status',
        'DecommitStatus',
        'Kind',
        'BoxId',
        'Guid',
        'NumStaticSlots',
        'ExpectedSlotCount',
        'Usage',
        'UsedSize',
        'AvailableSize',
        'TotalSize',
        'MaxReadThroughput',
        'MaxWriteThroughput',
        'MaxIOPS',
    ]
    visible_columns = [
        'NodeId:PDiskId',
        'FQDN',
        'Path',
        'Type',
        'Status',
        'DecommitStatus',
    ]
    col_units = {
        'Usage': '%',
        'UsedSize': 'bytes',
        'AvailableSize': 'bytes',
        'TotalSize': 'bytes'
    }
    right_align = {
        'Usage',
        'UsedSize',
        'AvailableSize',
        'TotalSize',
    }

    if args.show_pdisk_usage:
        visible_columns.extend(['Usage', 'UsedSize', 'AvailableSize', 'TotalSize'])

    table_output = table.TableOutput(
        all_columns,
        col_units=col_units,
        default_visible_columns=visible_columns,
        right_align=right_align)

    rows = []
    for pdisk in base_config.PDisk:
        row = {}
        row['NodeId:PDiskId'] = '[%u:%u]' % (pdisk.NodeId, pdisk.PDiskId)
        row['NodeId'] = pdisk.NodeId
        row['PDiskId'] = pdisk.PDiskId
        row['FQDN'] = node_to_fqdn[pdisk.NodeId]
        row['Path'] = pdisk.Path
        row['Status'] = kikimr_bsconfig.EDriveStatus.Name(pdisk.DriveStatus)
        row['DecommitStatus'] = kikimr_bsconfig.EDecommitStatus.Name(pdisk.DecommitStatus)
        row['Type'] = kikimr_bsconfig.EPDiskType.Name(pdisk.Type)
        row['BoxId'] = pdisk.BoxId
        row['Kind'] = pdisk.Kind
        row['Guid'] = pdisk.Guid
        row['NumStaticSlots'] = pdisk.NumStaticSlots
        row['ExpectedSlotCount'] = pdisk.ExpectedSlotCount
        row['AvailableSize'] = pdisk.PDiskMetrics.AvailableSize
        row['TotalSize'] = pdisk.PDiskMetrics.TotalSize
        row['UsedSize'] = pdisk.PDiskMetrics.TotalSize - pdisk.PDiskMetrics.AvailableSize
        row['Usage'] = row['UsedSize'] / pdisk.PDiskMetrics.TotalSize if pdisk.PDiskMetrics.TotalSize > 0 else 0.0
        row['MaxReadThroughput'] = pdisk.PDiskMetrics.MaxReadThroughput
        row['MaxWriteThroughput'] = pdisk.PDiskMetrics.MaxWriteThroughput
        row['MaxIOPS'] = pdisk.PDiskMetrics.MaxIOPS
        rows.append(row)

    table_output.dump(rows, args)



import ydb.core.protos.blobstorage_config_pb2 as kikimr_bsconfig
import ydb.core.protos.blobstorage_disk_color_pb2 as disk_color
import ydb.apps.dstool.lib.common as common
import sys
import re
from datetime import timedelta

description = 'Set cluster wide settings'


def add_options(p):
    g = p.add_mutually_exclusive_group(required=True)
    g.add_argument('--default-max-slots', type=int, help='Number of maximum slots for PDisks without explicit ExpectedSlotCount setting')
    g.add_argument('--enable-self-heal', action='store_const', const=True, dest='self_heal', help='Enable SelfHeal for cluster')
    g.add_argument('--disable-self-heal', action='store_const', const=False, dest='self_heal', help='Disable SelfHeal for cluster')
    g.add_argument('--enable-donor-mode', action='store_const', const=True, dest='donor_mode', help='Enable donor mode for cluster')
    g.add_argument('--disable-donor-mode', action='store_const', const=False, dest='donor_mode', help='Disable donor mode for cluster')
    g.add_argument('--scrub-periodicity', type=str, metavar='N', help='Scrub periodicity (in NdNhNmNs format or "disable")')
    g.add_argument('--pdisk-space-margin-promille', metavar='N', type=int, help='PDisk space margin measured in ‰')
    g.add_argument('--group-reserve-min', type=int, metavar='N', help='Group reserve constant minimum')
    g.add_argument('--group-reserve-part-ppm', type=int, metavar='N', help='Group reserve linear constant measured in PPM')
    g.add_argument('--max-scrubbed-disks-at-once', type=int, metavar='N', help='Maximum number of simultaneously scrubbed PDisks')
    choices = disk_color.TPDiskSpaceColor.E.keys()
    g.add_argument('--pdisk-space-color-border', choices=choices, help='PDisk space color border')
    choices = kikimr_bsconfig.TSerialManagementStage.E.keys()
    g.add_argument('--disk-management-mode', type=str, choices=choices, help='Disk management mode')
    common.add_basic_format_options(p)


def create_request(args):
    request = common.create_bsc_request(args)

    if args.disk_management_mode is not None:
        cmd = request.Command.add().MigrateToSerial
        cmd.Stage = kikimr_bsconfig.TSerialManagementStage.E.Value(args.disk_management_mode)
        return request

    cmd = request.Command.add().UpdateSettings
    if args.default_max_slots is not None:
        cmd.DefaultMaxSlots.append(args.default_max_slots)
    if args.self_heal is not None:
        cmd.EnableSelfHeal.append(args.self_heal)
    if args.donor_mode is not None:
        cmd.EnableDonorMode.append(args.donor_mode)
    if args.scrub_periodicity is not None:
        if args.scrub_periodicity == 'disable':
            d = timedelta()
        else:
            m = re.match(r'^((\d+)d)?((\d+)h)?((\d+)m)?((\d+)s)?$', args.scrub_periodicity)
            if m is None:
                raise Exception('Incorrect scrub periodicity format %s' % args.scrub_periodicity)
            d = timedelta(**dict(zip(['days', 'hours', 'minutes', 'seconds'], map(lambda x: int(x or 0), m.group(2, 4, 6, 8)))))
        cmd.ScrubPeriodicitySeconds.append(int(d.total_seconds()))
    if args.pdisk_space_margin_promille is not None:
        if args.pdisk_space_margin_promille < 0 or args.pdisk_space_margin_promille > 1000:
            raise Exception('Incorrect PDisk space margin setting %f' % args.pdisk_space_margin_promille)
        cmd.PDiskSpaceMarginPromille.append(args.pdisk_space_margin_promille)
    if args.group_reserve_min is not None:
        cmd.GroupReserveMin.append(args.group_reserve_min)
    if args.group_reserve_part_ppm is not None:
        cmd.GroupReservePartPPM.append(args.group_reserve_part_ppm)
    if args.max_scrubbed_disks_at_once is not None:
        cmd.MaxScrubbedDisksAtOnce.append(args.max_scrubbed_disks_at_once)
    if args.pdisk_space_color_border is not None:
        cmd.PDiskSpaceColorBorder.append(disk_color.TPDiskSpaceColor.E.Value(args.pdisk_space_color_border))

    return request


def perform_request(request):
    return common.invoke_bsc_request(request)


def is_successful_response(response):
    return common.is_successful_bsc_response(response)


def do(args):
    try:
        request = create_request(args)
        response = perform_request(request)
        common.print_request_result(args, request, response)
        if not is_successful_response(response):
            sys.exit(1)
    except Exception as e:
        common.print_status(args, success=False, error_reason=e)
        sys.exit(1)



import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table
from collections import defaultdict

description = 'List nodes'


def add_options(p):
    table.TableOutput([]).add_options(p)


def do(args):
    all_columns = [
        'NodeId',
        'FQDN',
        'IcPort',
        'DC',
        'Rack',
    ]
    visible_columns = [
        'NodeId',
        'FQDN',
        'IcPort',
        'DC',
        'Rack',
    ]

    table_output = table.TableOutput(all_columns, default_visible_columns=visible_columns)

    base_config = common.fetch_base_config()

    node_map = defaultdict(dict)
    for node in base_config.Node:
        node_data = node_map[node.NodeId]
        node_data['FQDN'] = node.HostKey.Fqdn
        node_data['IcPort'] = node.HostKey.IcPort
        node_data['DC'] = node.Location.DataCenter
        node_data['Rack'] = node.Location.Rack

    rows = []
    for node_id, node in node_map.items():
        row = {}
        row['NodeId'] = node_id
        for key, value in node.items():
            row[key] = value
        rows.append(row)

    table_output.dump(rows, args)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dydb/core/protos/metrics.proto\x12\x13NKikimrMetricsProto\"@\n\x11TMaximumValueUI64\x12\x1b\n\x13LastBucketStartTime\x18\x01 \x01(\x04\x12\x0e\n\x06Values\x18\x02 \x03(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.metrics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TMAXIMUMVALUEUI64._serialized_start=54
  _TMAXIMUMVALUEUI64._serialized_end=118
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tracing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dydb/core/protos/tracing.proto\x12\x0eNKikimrTracing\"2\n\x08TTraceID\x12\x14\n\x0c\x43reationTime\x18\x01 \x01(\x06\x12\x10\n\x08RandomID\x18\x02 \x01(\x06\"1\n\x11TSerializedSignal\x12\x0c\n\x04Type\x18\x01 \x01(\r\x12\x0e\n\x06Signal\x18\x02 \x01(\t\"\xd0\x01\n\x0cTTraceSignal\x12\x0c\n\x04Type\x18\x01 \x01(\r\x12(\n\x06SelfID\x18\x02 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12*\n\x08ParentID\x18\x03 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12(\n\x06RootID\x18\x04 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12\x32\n\x07Signals\x18\x05 \x03(\x0b\x32!.NKikimrTracing.TSerializedSignalB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tracing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TTRACEID._serialized_start=49
  _TTRACEID._serialized_end=99
  _TSERIALIZEDSIGNAL._serialized_start=101
  _TSERIALIZEDSIGNAL._serialized_end=150
  _TTRACESIGNAL._serialized_start=153
  _TTRACESIGNAL._serialized_end=361
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_tracing_signals.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tracing_pb2 as ydb_dot_core_dot_protos_dot_tracing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/tablet_tracing_signals.proto\x12\x0eNKikimrTracing\x1a&library/cpp/actors/protos/actors.proto\x1a\x1cydb/core/protos/tablet.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1dydb/core/protos/tracing.proto\"\xc1\x01\n\x0fTOnCancelTablet\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x10\n\x08TabletID\x18\x02 \x01(\x04\x12\x39\n\nTabletType\x18\x03 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x18\n\x10TabletDeadReason\x18\x04 \x01(\r\x12\x1b\n\x13SuggestedGeneration\x18\x05 \x01(\r\x12\x17\n\x0fKnownGeneration\x18\x06 \x01(\r\"\x89\x01\n\x12TOnTabletBootstrap\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x0e\n\x06Leader\x18\x02 \x01(\x08\x12\x1b\n\x13SuggestedGeneration\x18\x03 \x01(\r\x12\x33\n\x13StateStorageProxyID\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\"v\n TOnHandleStateStorageInfoResolve\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\x12\x11\n\tKnownStep\x18\x03 \x01(\r\x12\x13\n\x0bSignatureSz\x18\x04 \x01(\r\"q\n\x1bTOnLockedInitializationPath\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\x12\x11\n\tKnownStep\x18\x03 \x01(\r\x12\x13\n\x0bSignatureSz\x18\x04 \x01(\r\"s\n\x1dTOnHandleStateStorageInfoLock\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\x12\x11\n\tKnownStep\x18\x03 \x01(\r\x12\x13\n\x0bSignatureSz\x18\x04 \x01(\r\"C\n\x15TOnPromoteToCandidate\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\"~\n\x19TOnTabletBlockBlobStorage\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x35\n\x15ReqBlockBlobStorageID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x17\n\x0fKnownGeneration\x18\x03 \x01(\r\"\x9a\x01\n\x15TOnTabletRebuildGraph\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x37\n\x17TabletReqRebuildGraphID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x35\n\x13RebuildGraphTraceID\x18\x03 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\"i\n\x11TOnWriteZeroEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x10\n\x08Snapshot\x18\x02 \x01(\x04\x12\x15\n\rZeroConfirmed\x18\x03 \x01(\x04\x12\x18\n\x10LastInGeneration\x18\x04 \x01(\r\"\xb1\x01\n\x1aTOnFollowerPromoteToLeader\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x1b\n\x13SuggestedGeneration\x18\x02 \x01(\r\x12-\n\rKnownLeaderID\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x34\n\x14\x46ollowerStStGuardian\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\"?\n\x16TRebuildGraphBootstrap\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nBlockedGen\x18\x02 \x01(\r\"l\n\x18TErrorEntryBeyondBlocked\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12)\n\x06Latest\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x12\n\nBlockedGen\x18\x03 \x01(\r\"d\n\x13TErrorUnknownStatus\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x03 \x01(\t\"W\n\x17TErrorParsingFromString\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12)\n\x06\x42lobID\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"(\n\x13TErrorSendRefsCheck\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\"I\n\x12TErrorRebuildGraph\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Step\x18\x03 \x01(\r\"W\n\x12TOnProcessKeyEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12.\n\x0bLatestEntry\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"a\n\x13TOnProcessZeroEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x10\n\x08Snapshot\x18\x03 \x01(\x04\x12\x11\n\tConfirmed\x18\x04 \x01(\x04\"\x82\x02\n\x12TOnProcessLogEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12)\n\x06\x42lobID\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x10\n\x08Snapshot\x18\x03 \x01(\x04\x12\x11\n\tConfirmed\x18\x04 \x01(\x04\x12-\n\nReferences\x18\x05 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12/\n\x0cGcDiscovered\x18\x06 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12)\n\x06GcLeft\x18\x07 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\x8b\x01\n\x17TOnDiscoverRangeRequest\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\r\n\x05Group\x18\x02 \x01(\r\x12\'\n\x04\x46rom\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12%\n\x02To\x18\x04 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\x8a\x01\n\x16TOnApplyDiscoveryRange\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\r\n\x05Group\x18\x02 \x01(\r\x12\'\n\x04\x46rom\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12%\n\x02To\x18\x04 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"S\n\x0eTOnMakeHistory\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12.\n\x0bRefsToCheck\x18\x02 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\">\n\x15TOnCheckRefsGetResult\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nResponseSz\x18\x02 \x01(\r\"\xb3\x02\n\x14TOnBuildHistoryGraph\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12<\n\x07\x45ntries\x18\x02 \x03(\x0b\x32+.NKikimrTracing.TOnBuildHistoryGraph.TEntry\x1a\xc9\x01\n\x06TEntry\x12\x12\n\nGeneration\x18\x01 \x01(\r\x12\x0c\n\x04Step\x18\x02 \x01(\r\x12\x12\n\nIsSnapshot\x18\x03 \x01(\x08\x12-\n\nReferences\x18\x04 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12/\n\x0cGcDiscovered\x18\x05 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12)\n\x06GcLeft\x18\x06 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"C\n\x15TOnRebuildGraphResult\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fSerializedTrace\x18\x02 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_tracing_signals_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TONCANCELTABLET._serialized_start=194
  _TONCANCELTABLET._serialized_end=387
  _TONTABLETBOOTSTRAP._serialized_start=390
  _TONTABLETBOOTSTRAP._serialized_end=527
  _TONHANDLESTATESTORAGEINFORESOLVE._serialized_start=529
  _TONHANDLESTATESTORAGEINFORESOLVE._serialized_end=647
  _TONLOCKEDINITIALIZATIONPATH._serialized_start=649
  _TONLOCKEDINITIALIZATIONPATH._serialized_end=762
  _TONHANDLESTATESTORAGEINFOLOCK._serialized_start=764
  _TONHANDLESTATESTORAGEINFOLOCK._serialized_end=879
  _TONPROMOTETOCANDIDATE._serialized_start=881
  _TONPROMOTETOCANDIDATE._serialized_end=948
  _TONTABLETBLOCKBLOBSTORAGE._serialized_start=950
  _TONTABLETBLOCKBLOBSTORAGE._serialized_end=1076
  _TONTABLETREBUILDGRAPH._serialized_start=1079
  _TONTABLETREBUILDGRAPH._serialized_end=1233
  _TONWRITEZEROENTRY._serialized_start=1235
  _TONWRITEZEROENTRY._serialized_end=1340
  _TONFOLLOWERPROMOTETOLEADER._serialized_start=1343
  _TONFOLLOWERPROMOTETOLEADER._serialized_end=1520
  _TREBUILDGRAPHBOOTSTRAP._serialized_start=1522
  _TREBUILDGRAPHBOOTSTRAP._serialized_end=1585
  _TERRORENTRYBEYONDBLOCKED._serialized_start=1587
  _TERRORENTRYBEYONDBLOCKED._serialized_end=1695
  _TERRORUNKNOWNSTATUS._serialized_start=1697
  _TERRORUNKNOWNSTATUS._serialized_end=1797
  _TERRORPARSINGFROMSTRING._serialized_start=1799
  _TERRORPARSINGFROMSTRING._serialized_end=1886
  _TERRORSENDREFSCHECK._serialized_start=1888
  _TERRORSENDREFSCHECK._serialized_end=1928
  _TERRORREBUILDGRAPH._serialized_start=1930
  _TERRORREBUILDGRAPH._serialized_end=2003
  _TONPROCESSKEYENTRY._serialized_start=2005
  _TONPROCESSKEYENTRY._serialized_end=2092
  _TONPROCESSZEROENTRY._serialized_start=2094
  _TONPROCESSZEROENTRY._serialized_end=2191
  _TONPROCESSLOGENTRY._serialized_start=2194
  _TONPROCESSLOGENTRY._serialized_end=2452
  _TONDISCOVERRANGEREQUEST._serialized_start=2455
  _TONDISCOVERRANGEREQUEST._serialized_end=2594
  _TONAPPLYDISCOVERYRANGE._serialized_start=2597
  _TONAPPLYDISCOVERYRANGE._serialized_end=2735
  _TONMAKEHISTORY._serialized_start=2737
  _TONMAKEHISTORY._serialized_end=2820
  _TONCHECKREFSGETRESULT._serialized_start=2822
  _TONCHECKREFSGETRESULT._serialized_end=2884
  _TONBUILDHISTORYGRAPH._serialized_start=2887
  _TONBUILDHISTORYGRAPH._serialized_end=3194
  _TONBUILDHISTORYGRAPH_TENTRY._serialized_start=2993
  _TONBUILDHISTORYGRAPH_TENTRY._serialized_end=3194
  _TONREBUILDGRAPHRESULT._serialized_start=3196
  _TONREBUILDGRAPHRESULT._serialized_end=3263
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/key.proto\x12\x0cNKikimrProto\"V\n\nTKeyRecord\x12\x17\n\rContainerPath\x18\x01 \x01(\t:\x00\x12\r\n\x03Pin\x18\x02 \x01(\x0c:\x00\x12\x0c\n\x02Id\x18\x03 \x01(\t:\x00\x12\x12\n\x07Version\x18\x04 \x01(\x04:\x01\x30\"4\n\nTKeyConfig\x12&\n\x04Keys\x18\x01 \x03(\x0b\x32\x18.NKikimrProto.TKeyRecordB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.key_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TKEYRECORD._serialized_start=43
  _TKEYRECORD._serialized_end=129
  _TKEYCONFIG._serialized_start=131
  _TKEYCONFIG._serialized_end=183
# @@protoc_insertion_point(module_scope)



import ydb.apps.dstool.lib.common as common
import sys

description = 'Relocate vdisks to other pdisks'


def add_options(p):
    common.add_vdisk_ids_option(p, required=True)
    common.add_allow_unusable_pdisks_option(p)
    common.add_ignore_degraded_group_check_option(p)
    common.add_ignore_failure_model_group_check_option(p)
    common.add_ignore_vslot_quotas_option(p)
    p.add_argument('--move-only-to-operational-pdisks', action='store_true', help='Move VDisks only to operational PDisks')
    p.add_argument('--suppress-donor-mode', action='store_true', help='Do not leave the previous VDisk in donor mode after the moving and drop it')
    common.add_basic_format_options(p)


def create_request(args):
    base_config = common.fetch_base_config()
    vslots = common.get_vslots_by_vdisk_ids(base_config, args.vdisk_ids)

    vslot_ids = {common.get_vslot_id(vslot.VSlotId) for vslot in vslots if common.get_pdisk_id(vslot.VSlotId)}

    request = common.create_bsc_request(args)
    for vslot in base_config.VSlot:
        if common.get_vslot_id(vslot.VSlotId) not in vslot_ids:
            continue
        cmd = request.Command.add().ReassignGroupDisk
        cmd.GroupId = vslot.GroupId
        cmd.GroupGeneration = vslot.GroupGeneration
        cmd.FailRealmIdx = vslot.FailRealmIdx
        cmd.FailDomainIdx = vslot.FailDomainIdx
        cmd.VDiskIdx = vslot.VDiskIdx
        if args.suppress_donor_mode:
            cmd.SuppressDonorMode = True

    return request


def perform_request(request):
    return common.invoke_bsc_request(request)


def is_successful_response(response):
    return common.is_successful_bsc_response(response)


def do(args):
    request = create_request(args)
    response = perform_request(request)
    common.print_request_result(args, request, response)
    if not is_successful_response(response):
        sys.exit(1)



import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.grouptool as grouptool
import sys

description = 'Check groups'


def add_options(p):
    common.add_group_ids_option(p, required=True)
    g = p.add_mutually_exclusive_group(required=True)
    g.add_argument('--failure-model', action='store_true', help='Check failure model of groups')
    common.add_basic_format_options(p)


def check_failure_model(args):
    base_config_and_storage_pools = common.fetch_base_config_and_storage_pools()
    base_config = base_config_and_storage_pools['BaseConfig']
    storage_pools = base_config_and_storage_pools['StoragePools']

    pdisks_map = common.build_pdisk_map(base_config)
    storage_pool_groups_map = common.build_storage_pool_groups_map(base_config, args.group_ids)

    node_to_fdom = {
        node.NodeId: common.Location.from_location(node.Location, node.NodeId)
        for node in base_config.Node
    }

    node_to_dc_rack = {
        node.NodeId: node.Location.DataCenter + '::' + node.Location.Rack
        for node in base_config.Node
    }

    vslot_to_coordinates = {
        (id_.NodeId, id_.PDiskId, id_.VSlotId): (vslot.FailRealmIdx, vslot.FailDomainIdx, vslot.VDiskIdx)
        for vslot in base_config.VSlot
        for id_ in [vslot.VSlotId]
    }

    boxes = {}
    for box_id in set(sp.BoxId for sp in storage_pools):
        boxes[box_id] = [
            node_to_fdom[pdisk.NodeId]._replace(node=pdisk.NodeId, disk=pdisk.PDiskId)
            for pdisk in base_config.PDisk
            if pdisk.BoxId == box_id
        ]

    def geom_key(g):
        return g.RealmLevelBegin, g.RealmLevelEnd, g.DomainLevelBegin, g.DomainLevelEnd

    box_geoms = {}
    for box_id, geom in set((sp.BoxId, geom_key(sp.Geometry)) for sp in storage_pools):
        box_geoms[box_id, geom] = grouptool.decompose_location_map_by_levels(geom, boxes[box_id])

    success = True
    error_reason = ''
    for sp in storage_pools:
        sp_name = sp.Name
        location_id_map = box_geoms[sp.BoxId, geom_key(sp.Geometry)]

        for group in storage_pool_groups_map[sp.BoxId, sp.StoragePoolId]:
            location_map = {}
            vslot_map = {}
            for id_ in group.VSlotId:
                c = vslot_to_coordinates[id_.NodeId, id_.PDiskId, id_.VSlotId]
                location_map[c] = location_id_map[node_to_fdom[id_.NodeId]._replace(node=id_.NodeId, disk=id_.PDiskId)]
                vslot_map[c] = id_.NodeId, id_.PDiskId, id_.VSlotId

            # the following conditions must be met for the disks of every group:
            # 1. RealmPrefix is the same for all of the disks in the group
            # 2. All disks in the same realm must have the same RealmInfix; RealmInfix must differ for different realms
            # 3. DomainPrefix must be the same for all of the disks in same realm (but may or may not differ for different realms)
            # 4. DomainInfix must be different for every fail domain of the realm

            e = grouptool.check_group(location_map.items())
            if e:
                error_reason += 'Group %d from %s is ill-formed: %s\n' % (group.GroupId, sp_name, e)
                success = False
                prev = None
                row = []
                for c, (node_id, _, _) in sorted(vslot_map.items()):
                    if prev is not None and c[0] != prev[0]:
                        error_reason += ' '.join(row)
                        error_reason += '\n'
                        row = []
                    row.append(node_to_dc_rack[node_id])
                    prev = c
                if row:
                    error_reason += ' '.join(row)
                    error_reason += '\n'

            for id_ in group.VSlotId:
                pdisk = pdisks_map[id_.NodeId, id_.PDiskId]
                if not common.pdisk_matches_storage_pool(pdisk, sp):
                    error_reason += 'Group %d from %s contains incorrect PDisk\n' % (group.GroupId, sp_name)
                    success = False

    if not success:
        return False, error_reason
    return True, ''


def do(args):
    error_reason = ''
    success = True
    if args.failure_model:
        success, error_reason = check_failure_model(args)

    common.print_status(args, success, error_reason)
    if not success:
        sys.exit(1)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/protos/yql_mount.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/library/yql/protos/yql_mount.proto\x12\x0fNYqlMountConfig\"L\n\x0bTMountPoint\x12\x11\n\tRootAlias\x18\x01 \x02(\t\x12\x12\n\nMountPoint\x18\x02 \x02(\t\x12\x16\n\x07Library\x18\x03 \x01(\x08:\x05\x66\x61lse\"A\n\x0cTMountConfig\x12\x31\n\x0bMountPoints\x18\x01 \x03(\x0b\x32\x1c.NYqlMountConfig.TMountPointB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.protos.yql_mount_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TMOUNTPOINT._serialized_start=59
  _TMOUNTPOINT._serialized_end=135
  _TMOUNTCONFIG._serialized_start=137
  _TMOUNTCONFIG._serialized_end=202
# @@protoc_insertion_point(module_scope)
